@@ -13,14 +13,7 @@ from sos.collector.clusters import Cluster
 
 
 class satellite(Cluster):
-    """
-    This profile is specifically for Red Hat Satellite 6, and not earlier
-    releases of Satellite.
-
-    While note technically a 'cluster' in the traditional sense, Satellite
-    does provide for 'capsule' nodes which is what this profile aims to
-    enumerate beyond the 'primary' Satellite system.
-    """
+    """Red Hat Satellite 6"""
 
     cluster_name = 'Red Hat Satellite 6'
     packages = ('satellite', 'satellite-installer')
@@ -35,15 +28,13 @@ class satellite(Cluster):
         res = self.exec_primary_cmd(cmd, need_root=True)
         if res['status'] == 0:
             nodes = [
-                n.strip() for n in res['output'].splitlines()
+                n.strip() for n in res['stdout'].splitlines()
                 if 'could not change directory' not in n
             ]
             return nodes
         return []
 
     def set_node_label(self, node):
-        if node.address == self.primary.address:
+        if node.address == self.master.address:
             return 'satellite'
         return 'capsule'
-
-# vim: set et ts=4 sw=4 :
