@@ -23,9 +23,7 @@ class Ata(Plugin, IndependentPlugin):
         cmd_list = [
             "hdparm %(dev)s",
             "smartctl -a %(dev)s",
-            "smartctl -a %(dev)s -j",
-            "smartctl -l scterc %(dev)s",
-            "smartctl -l scterc %(dev)s -j"
+            "smartctl -l scterc %(dev)s"
         ]
         self.add_blockdev_cmd(cmd_list, whitelist=['sd.*', 'hd.*'])
 
