@@ -25,8 +25,6 @@ class ForemanInstaller(Plugin, DebianPlugin, UbuntuPlugin):
             "/etc/foreman-installer/*",
             "/var/log/foreman-installer/*",
             "/var/log/foreman-maintain/*",
-            "/var/lib/foreman-maintain/data.yml",
-            "/etc/foreman-maintain/foreman_maintain.yml",
             # specifically collect .applied files
             # that would be skipped otherwise as hidden files
             "/etc/foreman-installer/scenarios.d/*/.applied",
@@ -56,8 +54,8 @@ class ForemanInstaller(Plugin, DebianPlugin, UbuntuPlugin):
         # also hide passwords in yet different formats
         self.do_path_regex_sub(
             install_logs,
-            r"((\.|_|-)password(=\'|=|\", \"))(\w*)",
-            r"\1********")
+            r"(\.|_|-)password(=\'|=|\", \")(\w*)",
+            r"\1password\2********")
         self.do_path_regex_sub(
             "/var/log/foreman-installer/foreman-proxy*",
             r"(\s*proxy_password\s=) (.*)",
@@ -69,14 +67,14 @@ class ForemanInstaller(Plugin, DebianPlugin, UbuntuPlugin):
         # all scrubbing applied to configs must be applied to installer logs
         # as well, since logs contain diff of configs
         self.do_path_regex_sub(
-            r"(/etc/foreman-(installer|maintain)/(.*)((conf)(.*)?))|"
-            fr"({install_logs})",
+            r"(/etc/foreman-(installer|maintain)/(.*)((conf)(.*)?))|(%s)"
+            % install_logs,
             r"((\:|\s*)(passw|cred|token|secret|key).*(\:\s|=))(.*)",
             r"\1********")
         # yaml values should be alphanumeric
         self.do_path_regex_sub(
-            r"(/etc/foreman-(installer|maintain)/(.*)((yaml|yml)(.*)?))|"
-            fr"({install_logs})",
+            r"(/etc/foreman-(installer|maintain)/(.*)((yaml|yml)(.*)?))|(%s)"
+            % install_logs,
             r"((\:|\s*)(passw|cred|token|secret|key).*(\:\s|=))(.*)",
             r'\1"********"')
 
@@ -88,13 +86,13 @@ class RedHatForemanInstaller(ForemanInstaller, RedHatPlugin):
     def setup(self):
 
         self.add_file_tags({
-            '/var/log/foreman-installer/satellite.log':
-                ['foreman_satellite_log', 'satellite_installer_log'],
-            '/var/log/foreman-installer/capsule.log':
-                ['capsule_log', 'capsule_installer_log'],
+            '/var/log/foreman-installer/satellite.log.*':
+                ['insights_satellite_log' 'satellite_installer_log'],
+            '/var/log/foreman-installer/capsule.log.*':
+                ['insights_capsule_log' 'capsule_installer_log'],
         })
 
-        super().setup()
+        super(RedHatForemanInstaller, self).setup()
 
 
 # vim: set et ts=4 sw=4 :
