@@ -20,10 +20,12 @@ class OpenStackDesignate(Plugin):
 
     def setup(self):
         # collect current pool config
+        pools_cmd = self.fmt_container_cmd(
+            self.get_container_by_name(".*designate_central"),
+            "designate-manage pool generate_file --file /dev/stdout")
 
         self.add_cmd_output(
-            "designate-manage pool generate_file --file /dev/stdout",
-            container=self.get_container_by_name(".*designate_central"),
+            pools_cmd,
             suggest_filename="openstack_designate_current_pools.yaml"
         )
 
@@ -81,7 +83,7 @@ class OpenStackDesignate(Plugin):
             "ssl_key_password", "ssl_client_key_password",
             "memcache_secret_key"
         ]
-        regexp = r"(^\s*(%s)\s*=\s*)(.*)" % "|".join(protect_keys)
+        regexp = r"((?m)^\s*(%s)\s*=\s*)(.*)" % "|".join(protect_keys)
 
         self.do_path_regex_sub("/etc/designate/*", regexp, r"\1*********")
         self.do_path_regex_sub(
