@@ -3,14 +3,14 @@
 
 # for a description of the variables, please have a look at the
 # Glossary file, as written in the Porting folder, or use the url:
-# http://perl5.git.perl.org/perl.git/blob/HEAD:/Porting/Glossary
+# https://github.com/Perl/perl5/blob/blead/Porting/Glossary
 
 package Config;
 use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.030000";
+$VERSION = "5.032001";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.30.0) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.32.1) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.30.0
-    or die sprintf "%s: Perl lib version (5.30.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.32.1
+    or die sprintf "%s: Perl lib version (5.32.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/lib/x86_64-linux-gnu/perl/5.30',
+    archlibexp => '/usr/lib/x86_64-linux-gnu/perl/5.32',
     archname => 'x86_64-linux-gnu-thread-multi',
     cc => 'x86_64-linux-gnu-gcc',
     d_readlink => 'define',
@@ -93,19 +93,19 @@ tie %Config, 'Config', {
     dlsrc => 'dl_dlopen.xs',
     dont_use_nlink => undef,
     exe_ext => '',
-    inc_version_list => '',
+    inc_version_list => '5.32.0 5.32.0/x86_64-linux-gnu-thread-multi',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /usr/include/x86_64-linux-gnu /usr/lib /lib/x86_64-linux-gnu /lib/../lib /usr/lib/x86_64-linux-gnu /usr/lib/../lib /lib',
+    libpth => '/usr/local/lib /usr/include/x86_64-linux-gnu /usr/lib /lib/x86_64-linux-gnu /lib/../lib /usr/lib/x86_64-linux-gnu /usr/lib/../lib /lib /lib64 /usr/lib64',
     osname => 'linux',
     osvers => '4.19.0',
     path_sep => ':',
-    privlibexp => '/usr/share/perl/5.30',
+    privlibexp => '/usr/share/perl/5.32',
     scriptdir => '/usr/bin',
-    sitearchexp => '/usr/local/lib/x86_64-linux-gnu/perl/5.30.0',
-    sitelibexp => '/usr/local/share/perl/5.30.0',
+    sitearchexp => '/usr/local/lib/x86_64-linux-gnu/perl/5.32.1',
+    sitelibexp => '/usr/local/share/perl/5.32.1',
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.30.0',
+    version => '5.32.1',
 };
